try_track_decrease_mixnode_pledge

Function try_track_decrease_mixnode_pledge 

pub fn try_track_decrease_mixnode_pledge(
    owner: &str,
    amount: Coin,
    info: MessageInfo,
    deps: DepsMut<'_>,
) -> Result<Response, ContractError>
Tracks decreasing mixnode pledge. Invoked by the mixnet contract after successful event reconciliation. A separate BankMsg containing the specified amount was sent in the same transaction.